@@ -29,7 +29,6 @@ def upload_media(self, media: str, sender=None) -> Union[Dict[Any, Any], None]:
     if sender == None:
         sender = self.phone_number_id
 
-    url = f"https://graph.facebook.com/{self.instance.LATEST}/{sender}/media"
     form_data = {
         "file": (
             media,
@@ -45,16 +44,16 @@ def upload_media(self, media: str, sender=None) -> Union[Dict[Any, Any], None]:
     logging.info(f"Content-Type: {form_data.content_type}")
     logging.info(f"Uploading media {media}")
     r = requests.post(
-        url=url,
+        f"{self.base_url}/{sender}/media",
         headers=headers,
         data=form_data,
-    )
+        )
     if r.status_code == 200:
         logging.info(f"Media {media} uploaded")
         return r.json()
     logging.info(f"Error uploading media {media}")
     logging.info(f"Status code: {r.status_code}")
-    logging.debug(f"Response: {r.json()}")
+    logging.debug(f"Response: {r.json()}")  # Changed to debug level
     return None
 
 
@@ -73,7 +72,7 @@ def delete_media(self, media_id: str) -> Union[Dict[Any, Any], None]:
         return r.json()
     logging.info(f"Error deleting media {media_id}")
     logging.info(f"Status code: {r.status_code}")
-    logging.info(f"Response: {r.json()}")
+    logging.debug(f"Response: {r.json()}")  # Changed to debug level
     return None
 
 
@@ -100,7 +99,7 @@ def query_media_url(self, media_id: str) -> Union[str, None]:
         return r.json()["url"]
     logging.info(f"Media url not queried for {media_id}")
     logging.info(f"Status code: {r.status_code}")
-    logging.info(f"Response: {r.json()}")
+    logging.debug(f"Response: {r.json()}")  # Changed to debug level
     return None
 
 
